==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ANonvoidJimpleType.h <==
// public final class soot.jimple.parser.node.ANonvoidJimpleType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f7deda7dfb913a53 soot_jimple_parser_node_ANonvoidJimpleType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 745dd53d0856ed0 soot_jimple_parser_node_PJimpleType

// header file dependencies
// @dep_header soot_jimple_parser_node_PJimpleType

#include "soot/jimple/parser/node/PJimpleType.h"

#ifndef _JC_soot_jimple_parser_node_ANonvoidJimpleType_H_
#define _JC_soot_jimple_parser_node_ANonvoidJimpleType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PNonvoidType$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_refs	_jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_nonrefs	_jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$refs	_jc_soot_jimple_parser_node_ANonvoidJimpleType$refs;
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$nonrefs	_jc_soot_jimple_parser_node_ANonvoidJimpleType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object	_jc_soot_jimple_parser_node_ANonvoidJimpleType$object;

typedef const struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vmethods	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtable	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *);
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$_init$2c73afb22871bbc7(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANonvoidJimpleType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *);
extern struct _jc_soot_jimple_parser_node_PNonvoidType$object *_jc_soot_jimple_parser_node_ANonvoidJimpleType$method$getNonvoidType$be101fb7b05903db(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *);
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$setNonvoidType$cce5049cab1accc6(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANonvoidJimpleType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$getNonvoidType$be101fb7b05903db;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$setNonvoidType$cce5049cab1accc6;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *);
	struct _jc_soot_jimple_parser_node_PNonvoidType$object	*(*getNonvoidType$be101fb7b05903db)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setNonvoidType$cce5049cab1accc6)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PJimpleType$vmethods	soot_jimple_parser_node_PJimpleType;
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vmethods	soot_jimple_parser_node_ANonvoidJimpleType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_refs {
	struct _jc_soot_jimple_parser_node_PNonvoidType$object	*__5fnonvoidType__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$refs {
    _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_refs	soot_jimple_parser_node_ANonvoidJimpleType;
    _jc_soot_jimple_parser_node_PJimpleType$sub_refs	soot_jimple_parser_node_PJimpleType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PJimpleType$sub_nonrefs	soot_jimple_parser_node_PJimpleType;
    _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_nonrefs	soot_jimple_parser_node_ANonvoidJimpleType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object {
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype _jc_soot_jimple_parser_node_ANonvoidJimpleType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANonvoidJimpleType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANonvoidJimpleType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANonvoidJimpleType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ANonvoidJimpleType.h <==
// public final class soot.jimple.parser.node.ANonvoidJimpleType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f7deda7dfb913a53 soot_jimple_parser_node_ANonvoidJimpleType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 745dd53d0856ed0 soot_jimple_parser_node_PJimpleType

// header file dependencies
// @dep_header soot_jimple_parser_node_PJimpleType

#include "soot/jimple/parser/node/PJimpleType.h"

#ifndef _JC_soot_jimple_parser_node_ANonvoidJimpleType_H_
#define _JC_soot_jimple_parser_node_ANonvoidJimpleType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PNonvoidType$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_refs	_jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_nonrefs	_jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$refs	_jc_soot_jimple_parser_node_ANonvoidJimpleType$refs;
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$nonrefs	_jc_soot_jimple_parser_node_ANonvoidJimpleType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object	_jc_soot_jimple_parser_node_ANonvoidJimpleType$object;

typedef const struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vmethods	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtable	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$_init$2c73afb22871bbc7(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANonvoidJimpleType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PNonvoidType$object *_jc_soot_jimple_parser_node_ANonvoidJimpleType$method$getNonvoidType$be101fb7b05903db(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANonvoidJimpleType$method$setNonvoidType$cce5049cab1accc6(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANonvoidJimpleType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$getNonvoidType$be101fb7b05903db;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$setNonvoidType$cce5049cab1accc6;
extern _jc_method _jc_soot_jimple_parser_node_ANonvoidJimpleType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PNonvoidType$object	*(*getNonvoidType$be101fb7b05903db)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setNonvoidType$cce5049cab1accc6)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PJimpleType$vmethods	soot_jimple_parser_node_PJimpleType;
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vmethods	soot_jimple_parser_node_ANonvoidJimpleType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_refs {
	struct _jc_soot_jimple_parser_node_PNonvoidType$object	*__5fnonvoidType__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$refs {
    _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_refs	soot_jimple_parser_node_ANonvoidJimpleType;
    _jc_soot_jimple_parser_node_PJimpleType$sub_refs	soot_jimple_parser_node_PJimpleType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PJimpleType$sub_nonrefs	soot_jimple_parser_node_PJimpleType;
    _jc_soot_jimple_parser_node_ANonvoidJimpleType$sub_nonrefs	soot_jimple_parser_node_ANonvoidJimpleType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANonvoidJimpleType$object {
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANonvoidJimpleType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANonvoidJimpleType$vtype _jc_soot_jimple_parser_node_ANonvoidJimpleType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANonvoidJimpleType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANonvoidJimpleType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANonvoidJimpleType_H_ */
